diff --git a/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp b/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp
index 40d6b6d76452..f7d0515c8113 100644
--- a/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp
+++ b/src/ipa/rpi/cam_helper/cam_helper_ov5647.cpp
@@ -19,7 +19,7 @@ public:
 	double gain(uint32_t gainCode) const override;
 	unsigned int hideFramesStartup() const override;
 	unsigned int hideFramesModeSwitch() const override;
-	unsigned int mistrustFramesStartup() const override;
+	unsigned int mistrustMetadataStartup() const override;
 	unsigned int mistrustFramesModeSwitch() const override;
 
 private:
@@ -68,7 +68,7 @@ unsigned int CamHelperOv5647::hideFramesModeSwitch() const
 	return 2;
 }
 
-unsigned int CamHelperOv5647::mistrustFramesStartup() const
+unsigned int CamHelperOv5647::mistrustMetadataStartup() const
 {
 	/*
 	 * First couple of frames are under-exposed and are no good for control
diff --git a/src/ipa/rpi/cam_helper/cam_helper.cpp b/src/ipa/rpi/cam_helper/cam_helper.cpp
index dfdcd167839a..9afcf4bb52cf 100644
--- a/src/ipa/rpi/cam_helper/cam_helper.cpp
+++ b/src/ipa/rpi/cam_helper/cam_helper.cpp
@@ -192,9 +192,9 @@ unsigned int CamHelper::hideFramesModeSwitch() const
 	return 0;
 }
 
-unsigned int CamHelper::mistrustFramesStartup() const
+unsigned int CamHelper::mistrustMetadataStartup() const
 {
 	/* Many sensors return a single bad frame on start-up. */
 	return 1;
 }
 
@@ -192,9 +192,9 @@ unsigned int CamHelper::hideFramesModeSwitch() const
 {
-	/* Many sensors return a single bad frame on start-up. */
+	/* Many sensors return bad metadata on the first frame after start-up. */
 	return 1;
 }
diff --git a/src/ipa/rpi/cam_helper/cam_helper.h b/src/ipa/rpi/cam_helper/cam_helper.h
index bd101895f23e..3bbc74310670 100644
--- a/src/ipa/rpi/cam_helper/cam_helper.h
+++ b/src/ipa/rpi/cam_helper/cam_helper.h
@@ -56,7 +56,7 @@ namespace RPiController {
  * HideFramesModeSwitch(): Tell the pipeline handler not to return this
  *     many frames after a mode switch (other than start-up). Some sensors
  *     may produce innvalid frames after a mode switch; others may not.
  * MistrustFramesStartup(): At start-up a sensor may return frames for
  *    which we should not run any control algorithms (for example, metadata
  *    may be invalid).
  * MistrustFramesModeSwitch(): The number of frames, after a mode switch
@@ -96,7 +96,7 @@ public:
 	virtual double getModeSensitivity(const CameraMode &mode) const;
 	virtual unsigned int hideFramesStartup() const;
 	virtual unsigned int hideFramesModeSwitch() const;
-	virtual unsigned int mistrustFramesStartup() const;
+	virtual unsigned int mistrustMetadataStartup() const;
 	virtual unsigned int mistrustFramesModeSwitch() const;
 	virtual unsigned int getMinDebinFactor() const;
 
@@ -56,7 +56,7 @@ namespace RPiController {
  *     many frames after a mode switch (other than start-up). Some sensors
  *     may produce innvalid frames after a mode switch; others may not.
- * MistrustFramesStartup(): At start-up a sensor may return frames for
+ * mistrustMetadataStartup(): At start-up a sensor may return frames for
  *    which we should not run any control algorithms (for example, metadata
  *    may be invalid).
diff --git a/src/ipa/rpi/common/ipa_base.cpp b/src/ipa/rpi/common/ipa_base.cpp
index dacafa578c98..74517503ebc2 100644
--- a/src/ipa/rpi/common/ipa_base.cpp
+++ b/src/ipa/rpi/common/ipa_base.cpp
@@ -351,12 +351,11 @@ void IpaBase::start(const ControlList &controls, StartResult *result)
 	frameCount_ = 0;
 	if (firstStart_) {
 		invalidCount_ = helper_->hideFramesStartup();
-		mistrustCount_ = helper_->mistrustFramesStartup();
-
+		mistrustCount_ = helper_->mistrustMetadataStartup();
 		/*
 		 * Query the AGC/AWB for how many frames they may take to
 		 * converge sufficiently. Where these numbers are non-zero
 		 * we must allow for the frames with bad statistics
 		 * (mistrustCount_) that they won't see. But if zero (i.e.
 		 * no convergence necessary), no frames need to be dropped.
 		 */
@@ -351,12 +351,11 @@ void IpaBase::start(const ControlList &controls, StartResult *result)
 		 * Query the AGC/AWB for how many frames they may take to
 		 * converge sufficiently. Where these numbers are non-zero
-		 * we must allow for the frames with bad statistics
+		 * we must allow for the frames with bad metadata
 		 * (mistrustCount_) that they won't see. But if zero (i.e.
 		 * no convergence necessary), no frames need to be dropped.
